# unitorch.cli.models.llama

## LlamaProcessor

!!! tip
    **`core/process/llama`** is the section for configuration of LlamaProcessor.

::: unitorch.cli.models.llama.LlamaProcessor

## LlamaForClassification

!!! tip
    **`core/model/classification/llama`** is the section for configuration of LlamaForClassification.

::: unitorch.cli.models.llama.LlamaForClassification

## LlamaForPretrain

!!! tip
    **`core/model/pretrain/llama`** is the section for configuration of LlamaForPretrain.

::: unitorch.cli.models.llama.LlamaForPretrain

## LlamaForGeneration

!!! tip
    **`core/model/generation/llama`** is the section for configuration of LlamaForGeneration.

::: unitorch.cli.models.llama.LlamaForGeneration
